==> ingdao-0.0.13.tar.gz: example/counter/lib/datalayer/entity/updatedetailsweb.dart <==
import 'package:ingdao/dataflow/control/dfquery.dart';
import 'package:ingdao/dataflow/entity/dfbaseentity.dart';
import 'package:ingdao/dataflow/entity/dfwebentity.dart';
import 'package:ingdao/dataflow/field/dfbasefield.dart';
import 'package:ingdao/dataflow/field/dfwebfield.dart';
import '../field/update_details_field.dart';
import 'package:ingdao/dataflow/field/dffieldtype.dart';
import 'package:object_mapper/object_mapper.dart';

enum AppUpdateLevelType {
  updated,
  compulsoryUpdate,
  optionalUpdate
}

extension AppUpdateLevelTypeExtension on AppUpdateLevelType {

  int get value {
    switch (this) {
      case AppUpdateLevelType.updated:
        return 0;
      case AppUpdateLevelType.compulsoryUpdate:
        return 1;
      case AppUpdateLevelType.optionalUpdate:
        return 2;                
      default:
        return null;
    }
  }
}

class UpdateDetailsWeb extends DfWebEntity with UpdateDetailsField {

  static const REQ_DICT_FIELD_PLATFORM = "platform";
  static const REQ_DICT_FIELD_VERSION = "version";
  static const REQ_DICT_FIELD_APP_NAME = "appname";

  double topMarginRatio;
  String logoUrl;
  double logoWidth;
  double logoHeight;
  String appTitle;
  double appTitleSize;  
  String appTitleColor;
  String updateTitle;
  double updateTitleSize;
  String updateTitleColor;
  String version;
  String updateUrl;
  String updateUrlFailLaunchMessage;
  int updateLevel;
  String updateMessage;
  double updateMessageSize;
  String updateMessageColor;
  String backgroundColorTop;
  String backgroundColorBottom;
  String slideUpPanelColor;
  String butProceedText;
  String butProceedColor;
  String butLaterText;  
  String butLaterColor;
  String releaseNote;
  //Tank tank;
  //List<TsNote> notes;

  UpdateDetailsWeb ({double pTopMarginRatio, String pLogoUrl, double pLogoWidth, double pLogoHeight, String pAppTitle, double pAppTitleSize, String pAppTitleColor,
  String pUpdateTitle,  double pUpdateTitleSize,  String pUpdateTitleColor, String pVersion, String pUpdateUrl, String pUpdateUrlFailLaunchMessage,
  bool pUpdateLevel, String pUpdateMessage, double pUpdateMessageSize, String pUpdateMessageColor, String pBackgroundColorTop, String pBackgroundColorBottom,
  String pSlideUpPanelColor, String pButProceedText, String pButProceedColor, String pButLaterText, String pButLaterColor, String pReleaseNote
  }) : super(contextPath: "") {
    fTopMarginRatio = DfWebField(entity: this, name: "topMarginRatio", fieldType: DfFieldType.real(), getObjectValue: () => topMarginRatio, setObjectValue: (v) => topMarginRatio = v, value: pTopMarginRatio);
    fLogoUrl = DfWebField(entity: this, name: "logoUrl", fieldType: DfFieldType.text(), getObjectValue: () => logoUrl, setObjectValue: (v) => logoUrl = v, value: pLogoUrl);
    fLogoWidth = DfWebField(entity: this, name: "logoWidth", fieldType: DfFieldType.real(), getObjectValue: () => logoWidth, setObjectValue: (v) => logoWidth = v, value: pLogoWidth);
    fLogoHeight = DfWebField(entity: this, name: "logoHeight", fieldType: DfFieldType.real(), getObjectValue: () => logoHeight, setObjectValue: (v) => logoHeight = v, value: pLogoHeight);
    fAppTitle = DfWebField(entity: this, name: "appTitle", fieldType: DfFieldType.text(), getObjectValue: () => appTitle, setObjectValue: (v) => appTitle = v, value: pAppTitle);
    fAppTitleSize = DfWebField(entity: this, name: "appTitleSize", fieldType: DfFieldType.real(), getObjectValue: () => appTitleSize, setObjectValue: (v) => appTitleSize = v, value: pAppTitleSize);
    fAppTitleColor = DfWebField(entity: this, name: "appTitleColor", fieldType: DfFieldType.text(), getObjectValue: () => appTitleColor, setObjectValue: (v) => appTitleColor = v, value: pAppTitleColor);
    fUpdateTitle = DfWebField(entity: this, name: "updateTitle", fieldType: DfFieldType.text(), getObjectValue: () => updateTitle, setObjectValue: (v) => updateTitle = v, value: pUpdateTitle);
    fUpdateTitleSize = DfWebField(entity: this, name: "updateTitleSize", fieldType: DfFieldType.real(), getObjectValue: () => updateTitleSize, setObjectValue: (v) => updateTitleSize = v, value: pUpdateTitleSize);
    fUpdateTitleColor = DfWebField(entity: this, name: "updateTitleColor", fieldType: DfFieldType.text(), getObjectValue: () => updateTitleColor, setObjectValue: (v) => updateTitleColor = v, value: pUpdateTitleColor);
    fVersion = DfWebField(entity: this, name: "version", fieldType: DfFieldType.text(), getObjectValue: () => version, setObjectValue: (v) => version = v, value: pVersion);
    fUpdateUrl = DfWebField(entity: this, name: "updateUrl", fieldType: DfFieldType.text(), getObjectValue: () => updateUrl, setObjectValue: (v) => updateUrl = v, value: pUpdateUrl);
    fUpdateUrlFailLaunchMessage = DfWebField(entity: this, name: "updateUrlFailLaunchMessage", fieldType: DfFieldType.text(), getObjectValue: () => updateUrlFailLaunchMessage, setObjectValue: (v) => updateUrlFailLaunchMessage = v, value: pUpdateUrlFailLaunchMessage);
    fUpdateLevel = DfWebField(entity: this, name: "updateLevel", fieldType: DfFieldType.text(), getObjectValue: () => updateLevel, setObjectValue: (v) => updateLevel = v, value: pUpdateLevel);
    fUpdateMessage = DfWebField(entity: this, name: "updateMessage", fieldType: DfFieldType.text(), getObjectValue: () => updateMessage, setObjectValue: (v) => updateMessage = v, value: pUpdateMessage);
    fUpdateMessageSize = DfWebField(entity: this, name: "updateMessageSize", fieldType: DfFieldType.text(), getObjectValue: () => updateMessageSize, setObjectValue: (v) => updateMessageSize = v, value: pUpdateMessageSize);
    fUpdateMessageColor = DfWebField(entity: this, name: "updateMessageColor", fieldType: DfFieldType.text(), getObjectValue: () => updateMessageColor, setObjectValue: (v) => updateMessageColor = v, value: pUpdateMessageColor);
    fBackgroundColorTop = DfWebField(entity: this, name: "backgroundColorTop", fieldType: DfFieldType.text(), getObjectValue: () => backgroundColorTop, setObjectValue: (v) => backgroundColorTop = v, value: pBackgroundColorTop);
    fBackgroundColorBottom = DfWebField(entity: this, name: "backgroundColorBottom", fieldType: DfFieldType.text(), getObjectValue: () => backgroundColorBottom, setObjectValue: (v) => backgroundColorBottom = v, value: pBackgroundColorBottom);
    fSlideUpPanelColor = DfWebField(entity: this, name: "slideUpPanelColor", fieldType: DfFieldType.text(), getObjectValue: () => slideUpPanelColor, setObjectValue: (v) => slideUpPanelColor = v, value: pSlideUpPanelColor);
    fButProceedText = DfWebField(entity: this, name: "butProceedText", fieldType: DfFieldType.text(), getObjectValue: () => butProceedText, setObjectValue: (v) => butProceedText = v, value: pButProceedText);
    fButProceedColor = DfWebField(entity: this, name: "butProceedColor", fieldType: DfFieldType.text(), getObjectValue: () => butProceedColor, setObjectValue: (v) => butProceedColor = v, value: pButProceedColor);
    fButLaterText = DfWebField(entity: this, name: "butLaterText", fieldType: DfFieldType.text(), getObjectValue: () => butLaterText, setObjectValue: (v) => butLaterText = v, value: pButLaterText);
    fButLaterColor = DfWebField(entity: this, name: "butLaterColor", fieldType: DfFieldType.text(), getObjectValue: () => butLaterColor, setObjectValue: (v) => butLaterColor = v, value: pButLaterColor);
    fReleaseNote = DfWebField(entity: this, name: "releaseNote", fieldType: DfFieldType.text(), getObjectValue: () => releaseNote, setObjectValue: (v) => releaseNote = v, value: pReleaseNote);

    //fTank = DfWebField(entity: this, name: "tank", fieldType: DfFieldType.custom(), value: null);
    //fNotes = DfWebField(entity: this, name: "notes", fieldType: DfFieldType.custom(), value: null);
  }

  //Define what are the fields will map back the result from http response Map<String,dynamic>
  @override
  List<DfWebField> fields() {
     return [fTopMarginRatio,
            fLogoUrl,
            fLogoWidth,
            fLogoHeight,
            fAppTitle,
            fAppTitleSize,  
            fAppTitleColor,
            fUpdateTitle,
            fUpdateTitleSize,
            fUpdateTitleColor,
            fVersion,
            fUpdateUrl,
            fUpdateUrlFailLaunchMessage,
            fUpdateLevel,
            fUpdateMessage,
            fUpdateMessageSize,
            fUpdateMessageColor,
            fBackgroundColorTop,
            fBackgroundColorBottom,
            fSlideUpPanelColor,
            fButProceedText,
            fButProceedColor,
            fButLaterText,  
            fButLaterColor];
  }

  @override
  DfWebReqParam convertToWebReqParam(DfQuery query) {
    return null;
  }

  @override
  DfBaseEntity<DfBaseField> newInstance() {
    return UpdateDetailsWeb();
  }

  @override
  DfBaseEntity<DfWebField> jsonToObject(DfQueryPurpose purpose, Mapper map) {
    return null;
  }

  @override
  void customFieldJsonMap(Mapper map, List<DfWebField> fields) {
    // TODO: implement customFieldJsonMap
  }
}

==> ingdao-0.0.15.tar.gz: example/counter/lib/datalayer/entity/updatedetailsweb.dart <==
import 'package:ingdao/dataflow/control/dfquery.dart';
import 'package:ingdao/dataflow/entity/dfbaseentity.dart';
import 'package:ingdao/dataflow/entity/dfwebresponseentity.dart';
import 'package:ingdao/dataflow/field/dfbasefield.dart';
import 'package:ingdao/dataflow/field/dfwebfield.dart';
import '../field/update_details_field.dart';
import 'package:ingdao/dataflow/field/dffieldtype.dart';
import 'package:object_mapper/object_mapper.dart';

enum AppUpdateLevelType {
  updated,
  compulsoryUpdate,
  optionalUpdate
}

extension AppUpdateLevelTypeExtension on AppUpdateLevelType {

  int get value {
    switch (this) {
      case AppUpdateLevelType.updated:
        return 0;
      case AppUpdateLevelType.compulsoryUpdate:
        return 1;
      case AppUpdateLevelType.optionalUpdate:
        return 2;                
      default:
        return null;
    }
  }
}

class UpdateDetailsWeb extends DfWebResponseEntity with UpdateDetailsField {

  static const REQ_DICT_FIELD_PLATFORM = "platform";
  static const REQ_DICT_FIELD_VERSION = "version";
  static const REQ_DICT_FIELD_APP_NAME = "appname";

  double topMarginRatio;
  String logoUrl;
  double logoWidth;
  double logoHeight;
  String appTitle;
  double appTitleSize;  
  String appTitleColor;
  String updateTitle;
  double updateTitleSize;
  String updateTitleColor;
  String version;
  String updateUrl;
  String updateUrlFailLaunchMessage;
  int updateLevel;
  String updateMessage;
  double updateMessageSize;
  String updateMessageColor;
  String backgroundColorTop;
  String backgroundColorBottom;
  String slideUpPanelColor;
  String butProceedText;
  String butProceedColor;
  String butLaterText;  
  String butLaterColor;
  String releaseNote;
  bool active;
  //Tank tank;
  //List<TsNote> notes;

  UpdateDetailsWeb ({double pTopMarginRatio, String pLogoUrl, double pLogoWidth, double pLogoHeight, String pAppTitle, double pAppTitleSize, String pAppTitleColor,
  String pUpdateTitle,  double pUpdateTitleSize,  String pUpdateTitleColor, String pVersion, String pUpdateUrl, String pUpdateUrlFailLaunchMessage,
  bool pUpdateLevel, String pUpdateMessage, double pUpdateMessageSize, String pUpdateMessageColor, String pBackgroundColorTop, String pBackgroundColorBottom,
  String pSlideUpPanelColor, String pButProceedText, String pButProceedColor, String pButLaterText, String pButLaterColor, String pReleaseNote, bool pActive
  }) {
    fTopMarginRatio = DfWebField(entity: this, name: "topMarginRatio", fieldType: DfFieldType.real(), getObjectValue: () => topMarginRatio, setObjectValue: (v) => topMarginRatio = v, value: pTopMarginRatio);
    fLogoUrl = DfWebField(entity: this, name: "logoUrl", fieldType: DfFieldType.text(), getObjectValue: () => logoUrl, setObjectValue: (v) => logoUrl = v, value: pLogoUrl);
    fLogoWidth = DfWebField(entity: this, name: "logoWidth", fieldType: DfFieldType.real(), getObjectValue: () => logoWidth, setObjectValue: (v) => logoWidth = v, value: pLogoWidth);
    fLogoHeight = DfWebField(entity: this, name: "logoHeight", fieldType: DfFieldType.real(), getObjectValue: () => logoHeight, setObjectValue: (v) => logoHeight = v, value: pLogoHeight);
    fAppTitle = DfWebField(entity: this, name: "appTitle", fieldType: DfFieldType.text(), getObjectValue: () => appTitle, setObjectValue: (v) => appTitle = v, value: pAppTitle);
    fAppTitleSize = DfWebField(entity: this, name: "appTitleSize", fieldType: DfFieldType.real(), getObjectValue: () => appTitleSize, setObjectValue: (v) => appTitleSize = v, value: pAppTitleSize);
    fAppTitleColor = DfWebField(entity: this, name: "appTitleColor", fieldType: DfFieldType.text(), getObjectValue: () => appTitleColor, setObjectValue: (v) => appTitleColor = v, value: pAppTitleColor);
    fUpdateTitle = DfWebField(entity: this, name: "updateTitle", fieldType: DfFieldType.text(), getObjectValue: () => updateTitle, setObjectValue: (v) => updateTitle = v, value: pUpdateTitle);
    fUpdateTitleSize = DfWebField(entity: this, name: "updateTitleSize", fieldType: DfFieldType.real(), getObjectValue: () => updateTitleSize, setObjectValue: (v) => updateTitleSize = v, value: pUpdateTitleSize);
    fUpdateTitleColor = DfWebField(entity: this, name: "updateTitleColor", fieldType: DfFieldType.text(), getObjectValue: () => updateTitleColor, setObjectValue: (v) => updateTitleColor = v, value: pUpdateTitleColor);
    fVersion = DfWebField(entity: this, name: "version", fieldType: DfFieldType.text(), getObjectValue: () => version, setObjectValue: (v) => version = v, value: pVersion);
    fUpdateUrl = DfWebField(entity: this, name: "updateUrl", fieldType: DfFieldType.text(), getObjectValue: () => updateUrl, setObjectValue: (v) => updateUrl = v, value: pUpdateUrl);
    fUpdateUrlFailLaunchMessage = DfWebField(entity: this, name: "updateUrlFailLaunchMessage", fieldType: DfFieldType.text(), getObjectValue: () => updateUrlFailLaunchMessage, setObjectValue: (v) => updateUrlFailLaunchMessage = v, value: pUpdateUrlFailLaunchMessage);
    fUpdateLevel = DfWebField(entity: this, name: "updateLevel", fieldType: DfFieldType.text(), getObjectValue: () => updateLevel, setObjectValue: (v) => updateLevel = v, value: pUpdateLevel);
    fUpdateMessage = DfWebField(entity: this, name: "updateMessage", fieldType: DfFieldType.text(), getObjectValue: () => updateMessage, setObjectValue: (v) => updateMessage = v, value: pUpdateMessage);
    fUpdateMessageSize = DfWebField(entity: this, name: "updateMessageSize", fieldType: DfFieldType.text(), getObjectValue: () => updateMessageSize, setObjectValue: (v) => updateMessageSize = v, value: pUpdateMessageSize);
    fUpdateMessageColor = DfWebField(entity: this, name: "updateMessageColor", fieldType: DfFieldType.text(), getObjectValue: () => updateMessageColor, setObjectValue: (v) => updateMessageColor = v, value: pUpdateMessageColor);
    fBackgroundColorTop = DfWebField(entity: this, name: "backgroundColorTop", fieldType: DfFieldType.text(), getObjectValue: () => backgroundColorTop, setObjectValue: (v) => backgroundColorTop = v, value: pBackgroundColorTop);
    fBackgroundColorBottom = DfWebField(entity: this, name: "backgroundColorBottom", fieldType: DfFieldType.text(), getObjectValue: () => backgroundColorBottom, setObjectValue: (v) => backgroundColorBottom = v, value: pBackgroundColorBottom);
    fSlideUpPanelColor = DfWebField(entity: this, name: "slideUpPanelColor", fieldType: DfFieldType.text(), getObjectValue: () => slideUpPanelColor, setObjectValue: (v) => slideUpPanelColor = v, value: pSlideUpPanelColor);
    fButProceedText = DfWebField(entity: this, name: "butProceedText", fieldType: DfFieldType.text(), getObjectValue: () => butProceedText, setObjectValue: (v) => butProceedText = v, value: pButProceedText);
    fButProceedColor = DfWebField(entity: this, name: "butProceedColor", fieldType: DfFieldType.text(), getObjectValue: () => butProceedColor, setObjectValue: (v) => butProceedColor = v, value: pButProceedColor);
    fButLaterText = DfWebField(entity: this, name: "butLaterText", fieldType: DfFieldType.text(), getObjectValue: () => butLaterText, setObjectValue: (v) => butLaterText = v, value: pButLaterText);
    fButLaterColor = DfWebField(entity: this, name: "butLaterColor", fieldType: DfFieldType.text(), getObjectValue: () => butLaterColor, setObjectValue: (v) => butLaterColor = v, value: pButLaterColor);
    fReleaseNote = DfWebField(entity: this, name: "releaseNote", fieldType: DfFieldType.text(), getObjectValue: () => releaseNote, setObjectValue: (v) => releaseNote = v, value: pReleaseNote);
    fActive = DfWebField(entity: this, name: "active", fieldType: DfFieldType.boolean(), getObjectValue: () => active, setObjectValue: (v) => active = v, value: pActive);

    //fTank = DfWebField(entity: this, name: "tank", fieldType: DfFieldType.custom(), value: null);
    //fNotes = DfWebField(entity: this, name: "notes", fieldType: DfFieldType.custom(), value: null);
  }

  //Define what are the fields will map back the result from http response Map<String,dynamic>
  @override
  List<DfWebField> fields() {
     return [fTopMarginRatio,
            fLogoUrl,
            fLogoWidth,
            fLogoHeight,
            fAppTitle,
            fAppTitleSize,  
            fAppTitleColor,
            fUpdateTitle,
            fUpdateTitleSize,
            fUpdateTitleColor,
            fVersion,
            fUpdateUrl,
            fUpdateUrlFailLaunchMessage,
            fUpdateLevel,
            fUpdateMessage,
            fUpdateMessageSize,
            fUpdateMessageColor,
            fBackgroundColorTop,
            fBackgroundColorBottom,
            fSlideUpPanelColor,
            fButProceedText,
            fButProceedColor,
            fButLaterText,  
            fButLaterColor];
  }

  @override
  DfBaseEntity<DfBaseField> newInstance() {
    return UpdateDetailsWeb();
  }

  @override
  void customFieldJsonMap(Mapper map, List<DfWebField> fields) {
    // TODO: implement customFieldJsonMap
  }
}
